@@ -181,6 +181,7 @@ class GbpOptionParser(OptionParser):
                 'template-dir': '',
                 'time-machine': 1,
                 'track': 'True',
+                'track-missing': 'False',
                 'upstream-branch': 'upstream',
                 'upstream-tag': 'upstream/%(version)s',
                 'upstream-tree': 'TAG',
@@ -300,6 +301,9 @@ class GbpOptionParser(OptionParser):
         'track':
             "Set up tracking for remote branches, "
             "default is '%(track)s'",
+        'track-missing':
+            "Track missing remote branches, "
+            "default is '%(track-missing)s'",
         'author-is-committer':
             "Use the authors's name also as the committer's name, "
             "default is '%(author-is-committer)s'",
@@ -642,8 +646,11 @@ class GbpOptionParser(OptionParser):
         if not help:
             help = self.help[option_name]
         opt_names = self.get_opt_names(option_name)
+        default = kwargs.pop('default', None)
+        if default is None:
+            default = self.get_default(option_name, **kwargs)
         OptionParser.add_option(self, *opt_names, dest=dest,
-                                default=self.get_default(option_name, **kwargs),
+                                default=default,
                                 help=help % self.config, **kwargs)
 
     def add_boolean_config_file_option(self, option_name, dest):
@@ -736,8 +743,11 @@ class GbpOptionGroup(OptionGroup):
         if not help:
             help = self.parser.help[option_name]
         opt_names = self.parser.get_opt_names(option_name)
+        default = kwargs.pop('default', None)
+        if default is None:
+            default = self.parser.get_default(option_name, **kwargs)
         OptionGroup.add_option(self, *opt_names, dest=dest,
-                               default=self.parser.get_default(option_name, **kwargs),
+                               default=default,
                                help=help % self.parser.config, **kwargs)
 
     def add_boolean_config_file_option(self, option_name, dest):
