@@ -340,7 +340,7 @@ class GitRepository(object):
         @param rev: where to start the branch from
         @param force: reset branch HEAD to start point, if it already exists
 
-        If rev is None the branch starts form the current HEAD.
+        If rev is None the branch starts from the current HEAD.
         """
         args = GitArgs(branch)
         args.add_true(force, '--force')
@@ -610,7 +610,7 @@ class GitRepository(object):
 
         @param local_branch: name of the local branch
         @type local_branch: C{str}
-        @param upstream: remote/branch, for example origin/master
+        @param upstream: Remote branch in the form remote/branch, e.g. origin/master
         @type upstream: C{str}
         """
 
@@ -1645,7 +1645,7 @@ class GitRepository(object):
             raise GitRepositoryError("can't get %s: %s" % (id, stderr.decode().rstrip()))
         return obj
 
-    def grep_log(self, regex, since=None):
+    def grep_log(self, regex, since=None, merges=True):
         """
         Get commmits matching I{regex}
 
@@ -1654,13 +1654,13 @@ class GitRepository(object):
         @param since: where to start grepping (e.g. a branch)
         @type since: C{str}
         """
-        args = ['--pretty=format:%H']
-        args.append("--grep=%s" % regex)
-        if since:
-            args.append(since)
-        args.append('--')
+        args = GitArgs('--pretty=format:%H')
+        args.add_false(merges, '--no-merges')
+        args.add('--grep=%s' % regex)
+        args.add_true(since, since)
+        args.add('--')
 
-        stdout, stderr, ret = self._git_inout('log', args,
+        stdout, stderr, ret = self._git_inout('log', args.args,
                                               capture_stderr=True)
         if ret:
             raise GitRepositoryError("Error grepping log for %s: %s" %
