@@ -33,9 +33,10 @@ import gbp.log
 from gbp.patch_series import (PatchSeries, Patch)
 from gbp.scripts.common.pq import (is_pq_branch, pq_branch_name, pq_branch_base,
                                    parse_gbp_commands, format_patch,
-                                   switch_to_pq_branch, apply_single_patch,
-                                   apply_and_commit_patch, switch_pq,
-                                   drop_pq, get_maintainer_from_control)
+                                   apply_single_patch,
+                                   apply_and_commit_patch,
+                                   drop_pq, get_maintainer_from_control,
+                                   switch_to_pq_branch)
 from gbp.scripts.common import ExitCodes
 from gbp.dch import extract_bts_cmds
 
@@ -98,7 +99,8 @@ def generate_patches(repo, start, end, outdir, options):
             if 'topic' in cmds:
                 topic = cmds['topic']
             name = cmds.get('name', None)
-            format_patch(outdir, repo, info, patches, options.patch_numbers,
+            format_patch(outdir, repo, info, patches, options.abbrev,
+                         numbered=options.patch_numbers,
                          topic=topic, name=name,
                          renumber=options.renumber,
                          patch_num_prefix_format=options.patch_num_format)
@@ -127,7 +129,7 @@ def format_series_diff(added, removed, options):
     Format the patch differences into a suitable commit message
 
     >>> format_series_diff(['a'], ['b'], None)
-    'Rediff patches\\n\\nAdded a: <REASON>\\nDropped b: <REASON>\\n'
+    'Rediff patches\\n\\nAdd a: <REASON>\\nDrop b: <REASON>\\n'
     """
     if len(added) == 1 and not removed:
         # Single patch added, create a more thorough commit message
@@ -141,9 +143,9 @@ def format_series_diff(added, removed, options):
     else:
         msg = "Rediff patches\n\n"
         for p in added:
-            msg += 'Added %s: <REASON>\n' % p
+            msg += 'Add %s: <REASON>\n' % p
         for p in removed:
-            msg += 'Dropped %s: <REASON>\n' % p
+            msg += 'Drop %s: <REASON>\n' % p
     return msg
 
 
@@ -176,9 +178,9 @@ def commit_patches(repo, branch, patches, options, patch_dir):
 
 def find_upstream_commit(repo, branch, upstream_tag):
     """
-    Find commit corresponding upstream version based on changelog
+    Find commit corresponding to upstream version based on changelog
     """
-    vfs = gbp.git.vfs.GitVfs(repo, branch)
+    vfs = gbp.git.vfs.GitVfs(repo, pq_branch_base(branch))
     cl = DebianSource(vfs).changelog
     upstream_commit = repo.find_version(upstream_tag, cl.upstream_version)
     if not upstream_commit:
@@ -235,7 +237,7 @@ def export_patches(repo, branch, options):
             what = 'patches' if len(removed) > 1 else 'patch'
             gbp.log.info("Removed %s %s from patch series" % (what, ', '.join(removed)))
         else:
-            GitCommand('status', cwd=repo.path)(['--', PATCH_DIR])
+            gbp.log.info("Updated existing patches.")
 
     if options.drop:
         drop_pq(repo, branch)
@@ -290,8 +292,7 @@ def import_quilt_patches(repo, branch, series, tries, force, pq_from,
             pq_branch = pq_branch_name(branch)
             repo.checkout(branch)
         else:
-            gbp.log.err("Already on a patch-queue branch '%s' - doing nothing." % branch)
-            raise GbpError
+            raise GbpError("Already on a patch-queue branch '%s' - doing nothing." % branch)
     else:
         pq_branch = pq_branch_name(branch)
 
@@ -299,7 +300,7 @@ def import_quilt_patches(repo, branch, series, tries, force, pq_from,
         if force:
             drop_pq(repo, branch)
         else:
-            raise GbpError("Patch queue branch '%s'. already exists. Try 'rebase' instead."
+            raise GbpError("Patch queue branch '%s'. already exists. Try 'rebase' or 'switch' instead."
                            % pq_branch)
 
     maintainer = get_maintainer_from_control(repo)
@@ -352,20 +353,47 @@ def import_quilt_patches(repo, branch, series, tries, force, pq_from,
     return len(queue)
 
 
-def rebase_pq(repo, branch, pq_from, upstream_tag):
+def rebase_pq(repo, branch, options):
+    maybe_import_pq(repo, branch, options)
+    # Make sure we're on the pq branch
+    switch_to_pq_branch(repo, branch)
+    if pq_on_upstream_tag(options.pq_from):
+        base = find_upstream_commit(repo, branch, options.upstream_tag)
+    else:
+        base = pq_branch_base(repo.branch)
 
+    GitCommand("rebase", cwd=repo.path)([base])
+
+
+def import_pq(repo, branch, options):
+    """Import quilt patches onto pq branch"""
+    series = SERIES_FILE
+    tries = options.time_machine if (options.time_machine > 0) else 1
+    num = import_quilt_patches(repo, branch, series, tries,
+                               options.force, options.pq_from,
+                               options.upstream_tag)
+    gbp.log.info("%d patches listed in '%s' imported on '%s'" %
+                 (num, series, repo.get_branch()))
+
+
+def maybe_import_pq(repo, branch, options):
+    """Import quilt patches onto pq branch if pq branch does not exist yet"""
+    if not repo.has_branch(pq_branch_name(branch)):
+        gbp.log.info("No pq branch found, importing patches")
+        import_pq(repo, branch, options)
+        return True
+    return False
+
+
+def switch_pq(repo, branch, options):
+    """Switch to patch-queue branch if on base branch and vice versa"""
     if is_pq_branch(branch):
         base = pq_branch_base(branch)
+        gbp.log.info("Switching to %s" % base)
+        repo.checkout(base)
     else:
+        maybe_import_pq(repo, branch, options)
         switch_to_pq_branch(repo, branch)
-        base = branch
-
-    if pq_on_upstream_tag(pq_from):
-        _from = find_upstream_commit(repo, base, upstream_tag)
-    else:
-        _from = base
-
-    GitCommand("rebase", cwd=repo.path)([_from])
 
 
 def usage_msg():
@@ -399,6 +427,7 @@ def build_parser(name):
     parser.add_config_file_option(option_name="time-machine", dest="time_machine", type="int")
     parser.add_boolean_config_file_option("drop", dest='drop')
     parser.add_boolean_config_file_option(option_name="commit", dest="commit")
+    parser.add_config_file_option(option_name="abbrev", dest="abbrev", type="int")
     parser.add_option("--force", dest="force", action="store_true", default=False,
                       help="in case of import even import if the branch already exists")
     parser.add_config_file_option(option_name="color", dest="color", type='tristate')
@@ -456,24 +485,17 @@ def main(argv):
         if action == "export":
             export_patches(repo, current, options)
         elif action == "import":
-            series = SERIES_FILE
-            tries = options.time_machine if (options.time_machine > 0) else 1
-            num = import_quilt_patches(repo, current, series, tries,
-                                       options.force, options.pq_from,
-                                       options.upstream_tag)
-            current = repo.get_branch()
-            gbp.log.info("%d patches listed in '%s' imported on '%s'" %
-                         (num, series, current))
+            import_pq(repo, current, options)
         elif action == "drop":
             drop_pq(repo, current)
         elif action == "rebase":
-            rebase_pq(repo, current, options.pq_from, options.upstream_tag)
+            rebase_pq(repo, current, options)
         elif action == "apply":
             patch = Patch(patchfile)
             maintainer = get_maintainer_from_control(repo)
             apply_single_patch(repo, current, patch, maintainer, options.topic)
         elif action == "switch":
-            switch_pq(repo, current)
+            switch_pq(repo, current, options)
     except KeyboardInterrupt:
         retval = 1
         gbp.log.err("Interrupted. Aborting.")
