@@ -2,7 +2,7 @@
 """
 Test pristine-tar related methods in
 
-    - L{gbp.deb.DebianPristineTar}
+    - L{gbp.deb.pristinetar.DebianPristineTar}
 
 and
 
@@ -17,7 +17,7 @@ This testcase creates this reposity:
 import os
 from .. import context
 
-test_data = os.path.join(context.projectdir, "tests/test_PristineTar_data")
+test_data = os.path.join(context.projectdir, "tests/data/pristine_tar")
 dirs = {}
 
 
@@ -146,7 +146,8 @@ def test_pristine_tar_verify():
 
     >>> import gbp.deb.git
     >>> repo = gbp.deb.git.DebianGitRepository(dirs['repo'])
-    >>> repo.pristine_tar.verify('../upstream_1.0.orig.tar.gz')
+    >>> if repo.pristine_tar.has_feature_verify():
+    ...    repo.pristine_tar.verify('../upstream_1.0.orig.tar.gz')
     """
 
 
@@ -165,7 +166,7 @@ def test_pristine_tar_checkout_nonexistent():
     >>> repo.pristine_tar.checkout('upstream', '1.1', 'gzip', '..')
     Traceback (most recent call last):
     ...
-    CommandExecFailed: Pristine-tar couldn't checkout "upstream_1.1.orig.tar.gz": fatal: Path 'upstream_1.1.orig.tar.gz.delta' does not exist in 'refs/heads/pristine-tar'
+    gbp.command_wrappers.CommandExecFailed: Pristine-tar couldn't checkout "upstream_1.1.orig.tar.gz": fatal: Path 'upstream_1.1.orig.tar.gz.delta' does not exist in 'refs/heads/pristine-tar'
     pristine-tar: git show refs/heads/pristine-tar:upstream_1.1.orig.tar.gz.delta failed
     >>> gbp.log.err = _gbp_log_err_bak
     """
